@@ -37,7 +37,8 @@ theme_cowplot <- function(font_size = 14, font_family = "", line_size = .5) {
         margin = ggplot2::margin(r = small_size / 2, l = small_size / 4),
       ),
       axis.ticks        = element_line(colour = "black", size = line_size),
-      axis.line         = element_line(colour = "black", size = line_size),
+      axis.line.x       = element_line(colour = "black", size = line_size),
+      axis.line.y       = element_line(colour = "black", size = line_size),
       legend.key        = element_blank(),
       legend.margin     = grid::unit(0.1, "cm"),
       legend.key.size   = grid::unit(1, "lines"),
